@@ -49,6 +49,18 @@ sub myRoutines {
 	# we haven't been addressed, but we are still listening
     }
 
+    # from Chris Tessone: slashdot headlines
+    if(defined($param{'slash'}) and $message =~
+       /^\s*(slash|slashdot|headline|headlines|slashline|slashlines)\s*$/i) {
+      my $headlines = &getslashdotheads();
+      if ($msgType eq 'public') {
+        &say("$who: $headlines");
+      } else {
+        &msg($who, $headlines);
+      }
+      return "NOREPLY";
+    } 
+
      # Jonathan Feinberg's babel-bot  -- jdf++
      if (defined $param{babel} && 
        (1 or $addressed) && 
@@ -71,7 +83,7 @@ sub myRoutines {
      }
 
     # insult server.
-    if ($param{'insult'} and ($message =~ /^\s*insult (.*)\s*$/)) {
+    if (0 and $param{'insult'} and ($message =~ /^\s*insult (.*)\s*$/)) {
 	my $person = $1;
 	my $language = "english";
 	if ($person =~ s/ in (\S+)\s*$//i) {
